
#ifndef __PREF_SELECTION_H__
#define __PREF_SELECTION_H__

#include "defs.h"

GtkWidget*  pref_popupwnd_start();
void        pref_popupwnd_end(gboolean save);

GtkWidget*  pref_popupwnd_search_start();
void        pref_popupwnd_search_end(gboolean save);

struct _pref_popupwnd
{
    GtkWidget *interval, *maxchar, *width, *height, *hits, *method, *remember_pos;
} pref_popupwnd;

#endif /* __PREF_SELECTION_H__ */
